==> qtjambi-debuginfo-macos-5.15.18.jar: sources/QtJambiGui/QWhatsThisClickedEvent_shell.cpp <==
#include "QWhatsThisClickedEvent_shell.h"
#include <QtJambi/Cast>

void deleter_QWhatsThisClickedEvent(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QWhatsThisClickedEvent")
    QWhatsThisClickedEvent *_ptr = reinterpret_cast<QWhatsThisClickedEvent *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

QtJambiShell* QWhatsThisClickedEvent_shell::__shell() const { return *reinterpret_cast<QtJambiShell**>( quintptr(this) + sizeof(QWhatsThisClickedEvent_shell) ); }

jmethodID QWhatsThisClickedEvent_shell::__shell_javaMethod(int pos) const { return QWhatsThisClickedEvent_shell::__shell()->javaMethod(typeid(QWhatsThisClickedEvent), pos); }

// emitting (writeShellConstructor)
QWhatsThisClickedEvent_shell::QWhatsThisClickedEvent_shell(const QString& href0)
    : QWhatsThisClickedEvent(href0)
{
    QTJAMBI_IN_CONSTRUCTOR_CALL("QWhatsThisClickedEvent::QWhatsThisClickedEvent_shell(const QString& href0)", QWhatsThisClickedEvent_shell::__shell())
    QWhatsThisClickedEvent_shell::__shell()->constructed(typeid(QWhatsThisClickedEvent));
}

// emitting (writeShellDestructor)
QWhatsThisClickedEvent_shell::~QWhatsThisClickedEvent_shell()
{
    QTJAMBI_IN_DESTRUCTOR_CALL("QWhatsThisClickedEvent::~QWhatsThisClickedEvent()", QWhatsThisClickedEvent_shell::__shell())
    QWhatsThisClickedEvent_shell::__shell()->destructed(typeid(QWhatsThisClickedEvent));
}

void QWhatsThisClickedEvent_shell::operator delete(void * ptr) noexcept {
    reinterpret_cast<QWhatsThisClickedEvent_shell*>(ptr)->QWhatsThisClickedEvent_shell::__shell()->tryDeleteShell(typeid(QWhatsThisClickedEvent));
}

// emitting Virtual overrides (virtualFunctions)
// emitting Functions in shell class (nonVirtualShellFunctions)
// emitting Public Override Functions (publicOverrideFunctions)
// emitting Virtual Override Functions (virtualOverrideFunctions)
// emitting (writeConstructors)
// new QWhatsThisClickedEvent(QString)
void __qt_construct_QWhatsThisClickedEvent_0(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QWhatsThisClickedEvent(QString)")
    jstring href0 = static_cast<jstring>(__java_arguments[0].l);
    QString  __qt_href0 = qtjambi_cast<QString>(__jni_env, href0);
    QWhatsThisClickedEvent *__qt_this = new(__qtjambi_ptr) QWhatsThisClickedEvent_shell(__qt_href0);
    Q_UNUSED(__jni_object)
    Q_UNUSED(__qt_this)
}

// destruct QWhatsThisClickedEvent_shell
void __qt_destruct_QWhatsThisClickedEvent(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QWhatsThisClickedEvent")
    reinterpret_cast<QWhatsThisClickedEvent_shell*>(ptr)->~QWhatsThisClickedEvent_shell();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QWhatsThisClickedEvent::QWhatsThisClickedEvent(QString)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QWhatsThisClickedEvent_initialize_1native__Lio_qt_gui_QWhatsThisClickedEvent_2Ljava_lang_String_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jstring href0)
{
    QTJAMBI_NATIVE_METHOD_CALL("QWhatsThisClickedEvent::QWhatsThisClickedEvent(QString)")
    QTJAMBI_TRY {
        jvalue arguments;
        arguments.l = href0;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QWhatsThisClickedEvent_0, sizeof(QWhatsThisClickedEvent_shell), typeid(QWhatsThisClickedEvent), true, &deleter_QWhatsThisClickedEvent, &arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QWhatsThisClickedEvent::href()const
extern "C" Q_DECL_EXPORT jstring JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QWhatsThisClickedEvent_href_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jstring __java_return_value{0};
    QTJAMBI_TRY {
        const QWhatsThisClickedEvent *__qt_this = QtJambiAPI::objectFromNativeId<QWhatsThisClickedEvent>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QWhatsThisClickedEvent::href()const", __qt_this)
        QString __qt_return_value = __qt_this->href();
        __java_return_value = qtjambi_cast<jstring>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// emitting (writeJavaLangObjectOverrideFunctions)
// emitting (writeCloneFunction)

extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QWhatsThisClickedEvent_clone_1native)
(JNIEnv *__jni_env, jobject, QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value = nullptr;
    QTJAMBI_TRY {
        const QWhatsThisClickedEvent *__qt_this = QtJambiAPI::objectFromNativeId<QWhatsThisClickedEvent>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        __java_return_value = QtJambiAPI::convertNativeToJavaOwnedObjectAsWrapper(__jni_env, new QWhatsThisClickedEvent(*__qt_this));
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}


void initialize_meta_info_QWhatsThisClickedEvent(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerObjectTypeInfo<QWhatsThisClickedEvent>("QWhatsThisClickedEvent", "io/qt/gui/QWhatsThisClickedEvent");
// BEGIN: function table
    registerConstructorInfos(typeId, &__qt_destruct_QWhatsThisClickedEvent, {
        ConstructorInfo(&__qt_construct_QWhatsThisClickedEvent_0, "Ljava/lang/String;")
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QWhatsThisClickedEvent);
    registerSizeOfShell(typeId, sizeof(QWhatsThisClickedEvent_shell));
// END: type registration

// BEGIN: polymorphic ids
    registerDefaultPolymorphyHandler<QEvent, QWhatsThisClickedEvent>();
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}

==> qtjambi-debuginfo-macos-5.15.19.jar: sources/QtJambiGui/QWhatsThisClickedEvent_shell.cpp <==
#include "QWhatsThisClickedEvent_shell.h"
#include <QtJambi/Cast>

void deleter_QWhatsThisClickedEvent(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QWhatsThisClickedEvent")
    QWhatsThisClickedEvent *_ptr = reinterpret_cast<QWhatsThisClickedEvent *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

QtJambiShell* QWhatsThisClickedEvent_shell::__shell() const { return *reinterpret_cast<QtJambiShell**>( quintptr(this) + sizeof(QWhatsThisClickedEvent_shell) ); }

jmethodID QWhatsThisClickedEvent_shell::__shell_javaMethod(int pos) const { return QWhatsThisClickedEvent_shell::__shell()->javaMethod(typeid(QWhatsThisClickedEvent), pos); }

// emitting (writeShellConstructor)
QWhatsThisClickedEvent_shell::QWhatsThisClickedEvent_shell(const QString& href0)
    : QWhatsThisClickedEvent(href0)
{
    QTJAMBI_IN_CONSTRUCTOR_CALL("QWhatsThisClickedEvent::QWhatsThisClickedEvent_shell(const QString& href0)", QWhatsThisClickedEvent_shell::__shell())
    QWhatsThisClickedEvent_shell::__shell()->constructed(typeid(QWhatsThisClickedEvent));
}

QWhatsThisClickedEvent_shell::QWhatsThisClickedEvent_shell(const QWhatsThisClickedEvent& other0)
    : QWhatsThisClickedEvent(other0)
{
    QTJAMBI_IN_CONSTRUCTOR_CALL("QWhatsThisClickedEvent::QWhatsThisClickedEvent_shell(const QWhatsThisClickedEvent& other0)", QWhatsThisClickedEvent_shell::__shell())
    QWhatsThisClickedEvent_shell::__shell()->constructed(typeid(QWhatsThisClickedEvent));
}

// emitting (writeShellDestructor)
QWhatsThisClickedEvent_shell::~QWhatsThisClickedEvent_shell()
{
    QTJAMBI_IN_DESTRUCTOR_CALL("QWhatsThisClickedEvent::~QWhatsThisClickedEvent()", QWhatsThisClickedEvent_shell::__shell())
    QWhatsThisClickedEvent_shell::__shell()->destructed(typeid(QWhatsThisClickedEvent));
}

void QWhatsThisClickedEvent_shell::operator delete(void * ptr) noexcept {
    reinterpret_cast<QWhatsThisClickedEvent_shell*>(ptr)->QWhatsThisClickedEvent_shell::__shell()->tryDeleteShell(typeid(QWhatsThisClickedEvent));
}

// emitting Virtual overrides (virtualFunctions)
// emitting Functions in shell class (nonVirtualShellFunctions)
// emitting Public Override Functions (publicOverrideFunctions)
// emitting Virtual Override Functions (virtualOverrideFunctions)
// emitting (writeConstructors)
// new QWhatsThisClickedEvent(QString)
void __qt_construct_QWhatsThisClickedEvent_cref_QString(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QWhatsThisClickedEvent(QString)")
    jstring href0 = static_cast<jstring>(__java_arguments[0].l);
    QString  __qt_href0 = qtjambi_cast<QString>(__jni_env, href0);
    QWhatsThisClickedEvent *__qt_this = new(__qtjambi_ptr) QWhatsThisClickedEvent_shell(__qt_href0);
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__qt_this)
}

// QWhatsThisClickedEvent::QWhatsThisClickedEvent(QString)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QWhatsThisClickedEvent_initialize_1native__Lio_qt_gui_QWhatsThisClickedEvent_2Ljava_lang_String_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jstring href0)
{
    QTJAMBI_NATIVE_METHOD_CALL("QWhatsThisClickedEvent::QWhatsThisClickedEvent(QString)")
    QTJAMBI_TRY {
        jvalue arguments;
        arguments.l = href0;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QWhatsThisClickedEvent_cref_QString, sizeof(QWhatsThisClickedEvent_shell), typeid(QWhatsThisClickedEvent), true, &deleter_QWhatsThisClickedEvent, &arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// new QWhatsThisClickedEvent(QWhatsThisClickedEvent)
void __qt_construct_QWhatsThisClickedEvent_cref_QWhatsThisClickedEvent(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QWhatsThisClickedEvent(QWhatsThisClickedEvent)")
    jobject other0 = __java_arguments[0].l;
    const QWhatsThisClickedEvent& __qt_other0 = qtjambi_cast<const QWhatsThisClickedEvent& >(__jni_env, other0);
    QWhatsThisClickedEvent *__qt_this = new(__qtjambi_ptr) QWhatsThisClickedEvent_shell(__qt_other0);
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__qt_this)
}

// QWhatsThisClickedEvent::QWhatsThisClickedEvent(QWhatsThisClickedEvent)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QWhatsThisClickedEvent_initialize_1native__Lio_qt_gui_QWhatsThisClickedEvent_2Lio_qt_gui_QWhatsThisClickedEvent_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jobject other0)
{
    QTJAMBI_NATIVE_METHOD_CALL("QWhatsThisClickedEvent::QWhatsThisClickedEvent(QWhatsThisClickedEvent)")
    QTJAMBI_TRY {
        jvalue arguments;
        arguments.l = other0;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QWhatsThisClickedEvent_cref_QWhatsThisClickedEvent, sizeof(QWhatsThisClickedEvent_shell), typeid(QWhatsThisClickedEvent), true, &deleter_QWhatsThisClickedEvent, &arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// destruct QWhatsThisClickedEvent_shell
void __qt_destruct_QWhatsThisClickedEvent(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QWhatsThisClickedEvent")
    reinterpret_cast<QWhatsThisClickedEvent_shell*>(ptr)->~QWhatsThisClickedEvent_shell();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QWhatsThisClickedEvent::href()const
extern "C" Q_DECL_EXPORT jstring JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QWhatsThisClickedEvent_href_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jstring __java_return_value{0};
    QTJAMBI_TRY {
        const QWhatsThisClickedEvent *__qt_this = QtJambiAPI::objectFromNativeId<QWhatsThisClickedEvent>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QWhatsThisClickedEvent::href()const", __qt_this)
        QString __qt_return_value = __qt_this->href();
        __java_return_value = qtjambi_cast<jstring>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// emitting (writeJavaLangObjectOverrideFunctions)
// emitting (writeCloneFunction)

extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QWhatsThisClickedEvent_clone_1native)
(JNIEnv *__jni_env, jobject, QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value = nullptr;
    QTJAMBI_TRY {
        const QWhatsThisClickedEvent *__qt_this = QtJambiAPI::objectFromNativeId<QWhatsThisClickedEvent>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        __java_return_value = QtJambiAPI::convertNativeToJavaOwnedObjectAsWrapper(__jni_env, new QWhatsThisClickedEvent(*__qt_this));
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}


void initialize_meta_info_QWhatsThisClickedEvent(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerObjectTypeInfo<QWhatsThisClickedEvent>("QWhatsThisClickedEvent", "io/qt/gui/QWhatsThisClickedEvent");
// BEGIN: function table
    registerConstructorInfos(typeId, &__qt_destruct_QWhatsThisClickedEvent, {
        ConstructorInfo(&__qt_construct_QWhatsThisClickedEvent_cref_QString, "Ljava/lang/String;")
       ,ConstructorInfo(&__qt_construct_QWhatsThisClickedEvent_cref_QWhatsThisClickedEvent, "Lio/qt/gui/QWhatsThisClickedEvent;")
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QWhatsThisClickedEvent);
    registerSizeOfShell(typeId, sizeof(QWhatsThisClickedEvent_shell));
// END: type registration

// BEGIN: polymorphic ids
    registerDefaultPolymorphyHandler<QEvent, QWhatsThisClickedEvent>();
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}
